@@ -260,6 +260,13 @@ class GeoImage(mpop.imageo.image.Image):
                     srs.SetWellKnownGeogCS(area.proj_dict['ellps'])
                 except KeyError:
                     pass
+                try:
+                    # Check for epsg code.
+                    srs.SetAuthority('PROJCS', 'EPSG',
+                                     int(area.proj_dict['init'].
+                                         split('epsg:')[1]))
+                except (KeyError, IndexError):
+                    pass
                 srs = srs.ExportToWkt()
                 dst_ds.SetProjection(srs)
             except AttributeError:
