@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2010, 2011, 2012.
+# Copyright (c) 2010, 2011, 2012, 2013.
 
 # Author(s):
  
@@ -185,10 +185,10 @@ class ViirsCompositer(VisirCompositer):
     def green_snow(self):
         """Make a Green Snow RGB image composite.
         """
-        self.check_channels('M07', 'M10', 'M15')
+        self.check_channels('M05', 'M10', 'M15')
 
         ch1 = self['M10'].check_range()
-        ch2 = self['M07'].check_range()
+        ch2 = self['M05'].check_range()
         ch3 = -self['M15'].data
         
         img = geo_image.GeoImage((ch1, ch2, ch3),
@@ -202,15 +202,15 @@ class ViirsCompositer(VisirCompositer):
         
         return img
 
-    green_snow.prerequisites = set(['M07', 'M10', 'M15'])
+    green_snow.prerequisites = set(['M05', 'M10', 'M15'])
 
     def hr_green_snow(self):
         """Make a Green Snow RGB image composite.
         """
-        self.check_channels('I02', 'I03', 'I05')
+        self.check_channels('I01', 'I03', 'I05')
 
         ch1 = self['I03'].check_range()
-        ch2 = self['I02'].check_range()
+        ch2 = self['I01'].check_range()
         ch3 = -self['I05'].data
 
         img = geo_image.GeoImage((ch1, ch2, ch3),
@@ -224,7 +224,7 @@ class ViirsCompositer(VisirCompositer):
 
         return img
 
-    hr_green_snow.prerequisites = set(['I02', 'I03', 'I05'])
+    hr_green_snow.prerequisites = set(['I01', 'I03', 'I05'])
 
     def red_snow(self):
         """Make a Red Snow RGB image composite.
@@ -312,6 +312,75 @@ class ViirsCompositer(VisirCompositer):
 
     night_fog.prerequisites = set(['M12', 'M15', 'M16'])
 
+    def dust(self):
+        """Make a Dust RGB image composite.
+        """
+        self.check_channels('M14', 'M15', 'M16')
+
+        ch1 = self['M16'].data - self['M15'].data
+        ch2 = self['M15'].data - self['M14'].data
+        ch3 = self['M15'].data
+        img = geo_image.GeoImage((ch1, ch2, ch3),
+                                 self.area,
+                                 self.time_slot,
+                                 fill_value=(0, 0, 0),
+                                 mode="RGB",
+                                 crange=((-4, 2),
+                                         (0, 15),
+                                         (261, 289)))
+
+        img.enhance(gamma=(1.0, 2.5, 1.0))
+        
+        return img
+
+    dust.prerequisites = set(['M14', 'M15', 'M16'])
+
+
+    def ash(self):
+        """Make a Ash RGB image composite.
+        """
+        self.check_channels('M14', 'M15', 'M16')
+
+        ch1 = self['M16'].data - self['M15'].data
+        ch2 = self['M15'].data - self['M14'].data
+        ch3 = self['M15'].data
+        img = geo_image.GeoImage((ch1, ch2, ch3),
+                                 self.area,
+                                 self.time_slot,
+                                 fill_value=(0, 0, 0),
+                                 mode="RGB",
+                                 crange=((-4, 2),
+                                         (-4, 5),
+                                         (243, 303)))
+
+        return img
+
+    ash.prerequisites = set(['M14', 'M15', 'M16'])
+
+
+    def fog(self):
+        """Make a Fog RGB image composite.
+        """
+        self.check_channels('M14', 'M15', 'M16')
+
+        ch1 = self['M16'].data - self['M15'].data
+        ch2 = self['M15'].data - self['M14'].data
+        ch3 = self['M15'].data
+        img = geo_image.GeoImage((ch1, ch2, ch3),
+                                 self.area,
+                                 self.time_slot,
+                                 fill_value=(0, 0, 0),
+                                 mode="RGB",
+                                 crange=((-4, 2),
+                                         (0, 6),
+                                         (243, 283)))
+
+        img.enhance(gamma=(1.0, 2.0, 1.0))
+        
+        return img
+
+    fog.prerequisites = set(['M14', 'M15', 'M16'])
+
 
     def cloudtop(self):
         """Make a Cloudtop RGB image composite.
@@ -350,6 +419,24 @@ class ViirsCompositer(VisirCompositer):
     
     dnb.prerequisites = set(['DNB'])
 
+    def dnb_rgb(self, stretch="linear"):
+        """Make a RGB Day-Night band using M15 as blue."""
+        self.check_channels('DNB', 'M15')
+        ch1 = self['DNB'].data
+        ch2 = self['DNB'].data
+        ch3 = -self['M15'].data
+   
+        img =  geo_image.GeoImage((ch1, ch2, ch3),
+                                  self.area,
+                                  self.time_slot,
+                                  fill_value=(0, 0, 0),
+                                  mode="RGB")
+        if stretch:
+            img.enhance(stretch=stretch)
+        return img
+    
+    dnb_rgb.prerequisites = set(['DNB', 'M15'])
+
     def ir108(self):
         """Make a black and white image of the IR 10.8um channel.
         """
