@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Copyright (c) 2011, 2012.
+# Copyright (c) 2011, 2012, 2013.
 
 # SMHI,
 # Folkborgsvägen 1,
@@ -301,6 +301,7 @@ def load_viirs_sdr(satscene, options, *args, **kwargs):
 
     if not os.path.exists(directory):
         directory = globify(options["dir"]) % values
+        LOG.debug("Looking for files in directory " + str(directory))
         directories = glob.glob(directory)
         if len(directories) > 1:
             raise IOError("More than one directory for npp scene... " + 
@@ -314,14 +315,12 @@ def load_viirs_sdr(satscene, options, *args, **kwargs):
     file_list = glob.glob(os.path.join(directory, filename_tmpl))
     filenames = [ os.path.basename(s) for s in file_list ]
 
+    LOG.debug("Template = " + str(filename_tmpl))
     if len(file_list) > 22: # 22 VIIRS bands (16 M-bands + 5 I-bands + DNB)
         raise IOError("More than 22 files matching!")
     elif len(file_list) == 0:
-        #LOG.warning("No VIIRS SDR file matching!: " + os.path.join(directory,
-        #                                                           filename_tmpl))
         raise IOError("No VIIRS SDR file matching!: " + os.path.join(directory,
                                                                      filename_tmpl))
-        return
 
     geo_filenames_tmpl = strftime(satscene.time_slot, options["geo_filenames"]) %values
     geofile_list = glob.glob(os.path.join(directory, geo_filenames_tmpl))
@@ -423,8 +422,6 @@ def load_viirs_sdr(satscene, options, *args, **kwargs):
                                  filename=os.path.basename(dnb_geos[0]))
             else:
                 band.read_lonlat(directory)
-            dnb_lons = band.longitude
-            dnb_lats = band.latitude
 
         band_uid = band_desc + hashlib.sha1(band.data.mask).hexdigest()
         
